'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _q = require('q');

var _q2 = _interopRequireDefault(_q);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (environment, token) {
    var request = _request2.default.defaults({
        baseUrl: 'https://api.chatic.io/v1/node/' + environment + '/',
        headers: {
            Authorization: 'Bearer ' + token,
            Accept: 'application/json; charset=utf-8',
            'Content-Type': 'application/json'
        }
    });

    var call = function call(options) {
        var deferred = _q2.default.defer();

        request(options, function (error, httpResponse) {
            var body = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

            if (error) {
                deferred.reject(new Error(error));
                return;
            }

            if (httpResponse.statusCode === 200 && body.status !== 'Failed') {
                deferred.resolve({ body: body, httpResponse: httpResponse });
            } else {
                deferred.reject(new Error(error));
            }
        });

        return deferred.promise;
    };

    return {
        environment: environment,
        connect: function connect(body) {
            return call({ url: '/connect', method: 'POST', json: true, body: body });
        },
        disconnect: function disconnect() {
            return call({ url: '/disconnect', method: 'POST' });
        },
        send: function send(text, delay) {
            var url = '/sendtext';

            if (typeof delay === 'number') {
                url = url + '/' + delay;
            }

            return call({ url: url, method: 'POST', json: { text: text } }).then(function (response) {
                return response.body;
            });
        },
        click: function click(button, delay) {
            var url = '/clickbutton';

            if (typeof delay === 'number') {
                url = url + '/' + delay;
            }
            return call({ url: url, method: 'POST', json: { button: button } }).then(function (response) {
                return response.body;
            });
        }
    };
};