'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _mocha = require('mocha');

var _mocha2 = _interopRequireDefault(_mocha);

var _test = require('mocha/lib/test');

var _test2 = _interopRequireDefault(_test);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = _mocha2.default.interfaces.chatic = function (suite) {
    var suites = [suite];

    suite.on('pre-require', function (context, file, mocha) {
        var common = require('mocha/lib/interfaces/common')(suites, context, mocha);

        context.before = common.before;
        context.after = common.after;
        context.beforeEach = common.beforeEach;
        context.afterEach = common.afterEach;
        context.run = mocha.options.delay && common.runWithSuite(suite);

        context.describe = context.context = function (title, fn) {
            return common.suite.create({ title: title, file: file, fn: fn });
        };

        context.xdescribe = context.xcontext = context.describe.skip = function (title, fn) {
            return common.suite.skip({ title: title, file: file, fn: fn });
        };

        context.describe.only = function (title, fn) {
            return common.suite.only({ title: title, file: file, fn: fn });
        };

        context.describe.facebook = function (title, fn) {
            if (chatic.environment === 'facebook') {
                common.suite.create({ title: title, file: file, fn: fn });
            } else {
                common.suite.skip({ title: title, file: file, fn: fn });
            }
        };

        context.describe.slack = function (title, fn) {
            if (chatic.environment === 'slack') {
                common.suite.create({ title: title, file: file, fn: fn });
            } else {
                common.suite.skip({ title: title, file: file, fn: fn });
            }
        };

        context.it = context.specify = function (title, fn) {
            var suite = suites[0]; // eslint-disable-line

            if (suite.isPending()) {
                fn = null;
            }

            var test = new _test2.default(title, fn);

            test.file = file;
            suite.addTest(test);
            return test;
        };

        context.it.only = function (title, fn) {
            return common.test.only(mocha, context.it(title, fn));
        };

        context.xit = context.xspecify = context.it.skip = function (title) {
            return context.it(title);
        };

        context.it.facebook = function (title, fn) {
            if (chatic.environment === 'facebook') {
                context.it(title, fn);
            } else {
                context.it.skip(title);
            }
        };

        context.it.slack = function (title, fn) {
            if (chatic.environment === 'slack') {
                context.it(title, fn);
            } else {
                context.it.skip(title);
            }
        };

        context.it.retries = function (n) {
            return context.retries(n);
        };
    });
};